@@ -48,6 +48,7 @@ struct service {
 	int sgid;		/* true if an OP_SGID is in the opstream */
 	
 	int disabled;		/* if parse error in service declaration */
+	int internal;		/* if internal service */
 
 	rl_opcode_t run;	/* opstream to hook onto listening socket */
 	rl_opcode_t onexit;	/* opstream to run when child exits */
@@ -82,3 +83,5 @@ void newuserdata(struct userdata **);
 void userdata_copy(struct userdata **, struct userdata *);
 
 #endif /* !H_DATA */
+
+/* vim: set ts=2: */
