@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: update-inetd.sh,v 1.3 2005/01/04 17:13:12 robert Exp $
+# $Id: update-inetd.sh,v 1.4 2005/02/24 20:17:04 robert Exp $
 #
 # rlinetd's version of update-inetd.
 # Robert Luberda <robert@debian.org>, Aug 2001
@@ -9,7 +9,7 @@ set -e
 
 PATH=/usr/sbin:$PATH
 
-version='$Revision: 1.3 $'
+version='$Revision: 1.4 $'
 line=""
 last=""
 
@@ -40,7 +40,7 @@ fi
 
 
 if [ "x$line" != "x" ] ; then
-	echo "$line" | inetd2rlinetd  /etc/rlinetd.d
+	inetd2rlinetd  -l "$line" /etc/rlinetd.d
 
 	# reload configuration
 	killall -HUP rlinetd || true
