@@ -180,6 +180,8 @@ static void fdops_grow(struct fd_ops **ops, int *len, int new) {
 	if(new < *len)
 		return;
 	*ops = realloc(*ops, (new + 1) * sizeof(**ops));
+	if (!*ops)
+		rl_fatal(EX_SOFTWARE, "ABORT - Can't allocate memory");
 	*len = new + 1;
 }
 
@@ -228,6 +230,8 @@ struct rl_instance *inst_new() {
 	struct rl_instance *i;
 
 	i = malloc(sizeof(*i));
+	if (!i)
+		rl_fatal(EX_SOFTWARE, "ABORT - Can't allocate memory");
 	memset(i, 0, sizeof(*i));
 	return i;
 }
@@ -242,3 +246,5 @@ void inst_free(struct rl_instance *i) {
 	}
 	free(i);
 }
+
+/* vim: set ts=2: */
