@@ -22,6 +22,8 @@ int rl_readfile(char *path, void **addr, int *len) {
 		return -1;
 	}
 	tmp = malloc(st.st_size);
+	if (!tmp)
+		rl_fatal(EX_SOFTWARE, "ABORT - Can't allocate memory");
 	if(read(fd, tmp, st.st_size) < 0) {
 		rl_warn("Failed to inhale file %s", path);
 		free(tmp);
@@ -33,3 +35,5 @@ int rl_readfile(char *path, void **addr, int *len) {
 	*len = st.st_size;
 	return 0;
 }
+
+/* vim: set ts=2: */
